@@ -61,7 +61,7 @@ class ADLSWriter(Writer):
             filename = blob_location + str(i) + ".csv"
             block_blob_service.create_blob_from_text(self.container_name + "/" + self.dataflow_name, 
                                                      filename, dataframe)
-            blob_url = 'https://' + self.storage_name + '.dfs.core.windows.net/' + self.container_name + '/' + filename
+            blob_url = 'https://' + self.storage_name + '.dfs.core.windows.net/' + self.container_name + '/' + self.dataflow_name + '/' + filename
             result.append((filename, blob_url))
         return result
 
@@ -76,5 +76,5 @@ class ADLSWriter(Writer):
         block_blob_service.create_blob_from_text(self.container_name, self.dataflow_name+"/"+ blob_location, json_dict, lease_id=lease_id)
         if lease_id:
             block_blob_service.release_blob_lease(self.container_name, self.dataflow_name+"/"+ blob_location, lease_id)
-        blob_url = 'https://'+self.storage_name+'.dfs.core.windows.net/'+self.container_name+'/'+blob_location
+        blob_url = 'https://' + self.storage_name + '.dfs.core.windows.net/' + self.container_name + '/' + self.dataflow_name + '/' + blob_location
         return blob_url
