@@ -386,14 +386,17 @@ class Model(DataObject):
         second_to_attribute = second_relationship.toAttribute
         same_from = False
         same_to = False
-        if first_from_attribute.entityName.lower() == second_from_attribute.entityName.lower() and first_from_attribute.attributeName.lower() == second_from_attribute.attributeName.lower():
-            same_from = True
+        try:
+            if first_from_attribute.entityName.lower() == second_from_attribute.entityName.lower() and first_from_attribute.attributeName.lower() == second_from_attribute.attributeName.lower():
+                same_from = True
 
-        if first_to_attribute.entityName.lower() == second_to_attribute.entityName.lower() and first_to_attribute.attributeName.lower() == second_to_attribute.attributeName.lower():
-            same_to = True
-        
-        if same_from and same_to:
-            return True
+            if first_to_attribute.entityName.lower() == second_to_attribute.entityName.lower() and first_to_attribute.attributeName.lower() == second_to_attribute.attributeName.lower():
+                same_to = True
+            
+            if same_from and same_to:
+                return True
+        except Exception as e:
+            print(str(e))
         return False
 
     def read_from_storage(self, entity_name, reader, fn=None, lit=None):
